@@ -19,6 +19,7 @@ SERVICE_RENAMES = {
     'alexaforbusiness': 'alexa-for-business',
     'apigateway': 'api-gateway',
     'application-autoscaling': 'application-auto-scaling',
+    'appmesh': 'app-mesh',
     'autoscaling': 'auto-scaling',
     'autoscaling-plans': 'auto-scaling-plans',
     'ce': 'cost-explorer',
@@ -40,11 +41,13 @@ SERVICE_RENAMES = {
     'elbv2': 'elastic-load-balancing-v2',
     'es': 'elasticsearch-service',
     'events': 'cloudwatch-events',
+    'globalaccelerator': 'global-accelerator',
     'iot-data': 'iot-data-plane',
     'iot-jobs-data': 'iot-jobs-data-plane',
     'iot1click-devices': 'iot-1click-devices-service',
     'iot1click-projects': 'iot-1click-projects',
     'kinesisanalytics': 'kinesis-analytics',
+    'kinesisanalyticsv2': 'kinesis-analytics-v2',
     'kinesisvideo': 'kinesis-video',
     'lex-models': 'lex-model-building-service',
     'lex-runtime': 'lex-runtime-service',
@@ -54,9 +57,11 @@ SERVICE_RENAMES = {
     'marketplace-entitlement': 'marketplace-entitlement-service',
     'meteringmarketplace': 'marketplace-metering',
     'mgh': 'migration-hub',
+    'sms-voice': 'pinpoint-sms-voice',
     'resourcegroupstaggingapi': 'resource-groups-tagging-api',
     'route53': 'route-53',
     'route53domains': 'route-53-domains',
+    's3control': 's3-control',
     'sdb': 'simpledb',
     'secretsmanager': 'secrets-manager',
     'serverlessrepo': 'serverlessapplicationrepository',
